AIModel class abstract

Implementers

Constructors

AIModel()

Properties

defaultModel ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
modelType ↔ AiModelType
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getStatus() → AIStatus
getTextAndDocumentCompletion(String text, List<Uint8List> files) → Future<String?>
getTextCompletion(String text) → Future<String?>
initialize() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
testModel() → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited