AiModelType class

Constructors

AiModelType({String typeName = ''})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeName String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Properties

all List<AiModelType>
no setter
gemini AiModelType
getter/setter pair
openAi AiModelType
getter/setter pair

Static Methods

fromMap(Map map) AiModelType
fromString(String value) AiModelType