AIStatus class

Constructors

AIStatus({String statusName = ''})

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusName ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

active ↔ AIStatus
getter/setter pair
inactive ↔ AIStatus
getter/setter pair
notConfigured ↔ AIStatus
getter/setter pair
tokenLimitError ↔ AIStatus
getter/setter pair

Static Methods

fromMap(Map map) → AIStatus
fromString(String value) → AIStatus