GeminiAI class

Implemented types

Constructors

GeminiAI()

Properties

apiKey ↔ String
getter/setter pair
defaultModel ↔ bool
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pairoverride
lastStatus ↔ AIStatus
getter/setter pair
lastStatusCheckedTime ↔ DateTime?
getter/setter pair
modelType ↔ AiModelType
getter/setter pairoverride
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getStatus() → AIStatus
override
getTextAndDocumentCompletion(String text, List<Uint8List> files) → Future<String?>
override
getTextCompletion(String text) → Future<String?>
override
initialize() → Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setApiKey(String k) → Future<bool>
setDefaultModel(bool value) → void
setStatusBasedOnError(dynamic e) → void
testModel() → Future<bool>
override
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map map) → GeminiAI

Constants

modelName → const String
Always target the newest Gemini Flash. gemini-flash-latest is Google's alias that tracks the current Flash model, so this keeps working as older versions (e.g. gemini-1.5-flash) are retired.