AiProviderSpec class

Constructors

AiProviderSpec({required AiModelType type, required String displayName, required String apiKeyUrl, required List<String> addSteps, required AIModel create()})
const

Properties

addSteps → List<String>
final
apiKeyUrl → String
final
create → AIModel Function()
final
displayName → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → AiModelType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited