ManagerAI class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
addModel(
AIModel aiModel) → Future< List< AIModel> > -
createAIModel(
AiModelType type, String apiKey) → Future< AIModel> -
deleteModel(
AIModel aiModel) → Future< List< AIModel> > -
getActiveModel(
) → Future< AIModel?> -
getAiModelAddSteps(
AiModelType type) → List< String> -
getAiModelApiKeyURL(
AiModelType type) → String -
getDefaultModel(
) → Future< AIModel?> -
getRotationSettings(
) → Future< RotationSettings> -
loadAllModels(
) → Future< List< AIModel> > -
saveModels(
List< AIModel> inputAIModels) → Future<List< AIModel> > -
setDefaultModel(
AIModel aiModel) → Future< List< AIModel> > -
setInRotation(
AIModel aiModel, bool inRotation) → Future< List< AIModel> > -
setRotationMode(
RotationMode mode) → Future< void> -
setRotationOrder(
List< AIModel> ordered) → Future<List< AIModel> >