ManagerAIDatabase class

Constructors

ManagerAIDatabase()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

database → Future<Database>
no setter

Static Methods

deleteMap(String id) → Future<void>
loadAll() → Future<List<Map>>
loadMap(String id) → Future<Map?>
saveMap(String id, Map data) → Future<Map>

Constants

dbName → const String