UtilsCommon class

Constructors

UtilsCommon()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

celsiusToFahrenheit(double celsius) → double
dToStr(dynamic quantity, {int decimalPlaces = 2}) → String
fahrenheitToCelsius(double fahrenheit) → double
generateId() → String
getCurrentTime() → String
getGreetings() → String
getRangeList(double quantity) → List<double>
log(dynamic message, {bool isError = false, dynamic error}) → void
toDouble(dynamic value) → double
toInt(dynamic value) → int