ManagerAI class

Constructors

ManagerAI()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

aiModelTypeAddSteps ↔ Map<AiModelType, List<String>>
getter/setter pair
aiModelTypeApiKeyURL ↔ Map<AiModelType, String>
getter/setter pair

Static Methods

addModel(AIModel aiModel) → Future<List<AIModel>>
createAIModel(AiModelType aiModelType, String apiKey) → Future<AIModel>
Create an AI Model based on the type and API key
deleteModel(AIModel aiModel) → Future<List<AIModel>>
getAiModelAddSteps(AiModelType aiModelType) → List<String>
getAiModelApiKeyURL(AiModelType aiModelType) → String
getDefaultModel() → Future<AIModel?>
loadAllModels() → Future<List<AIModel>>
saveModels(List<AIModel> inputAIModels) → Future<List<AIModel>>
setDefaultModel(AIModel aiModel) → Future<List<AIModel>>